from typing import List, Literal, Optional, Any
from typing_extensions import TypedDict, NotRequired

class SafetyItem(TypedDict):
    safety: str
    isSafe: bool
    score: int

class GreetingItem(TypedDict):
    greeting_type: str
    isPresent: bool

class Data(TypedDict):
    safety: NotRequired[Optional[List[SafetyItem]]]
    compliance: NotRequired[Optional[List]]
    pii: NotRequired[Optional[List]]
    greetings: NotRequired[Optional[List[GreetingItem]]]

class GuardRailResponse(TypedDict):
    success: bool
    statusCode:int
    message:NotRequired[Optional[str]]
    errorCode:NotRequired[Optional[str]]
    data: NotRequired[Optional[Data]]
    details: NotRequired[Optional[Any]]

class TextInput(TypedDict):
    role: str
    content: str



from typing import Any, Dict, List, Optional, Union
from typing_extensions import TypedDict, NotRequired

class ConversationEntry(TypedDict):
    role: str
    content: str

class Data(TypedDict, total=False):  # total=False allows optional keys
    success: bool
    statusCode: int
    remark: str
    error: Any  # can be str or None
    input: Union[str, List[ConversationEntry]]
    masked_conversation: Optional[List[ConversationEntry]]
    masked_text: Optional[str]
    mapping: Dict[str, str]

class PIIResponse(TypedDict):
    success: bool
    statusCode:int
    message:NotRequired[Optional[str]]
    errorCode:NotRequired[Optional[str]]
    data: NotRequired[Optional[Data]]
    details: NotRequired[Optional[Any]]